@@ -1,5 +1,6 @@
 from .Gus import Client
 import re
+from agile.StoryParser import StoryParser
 
 class BacklogClient(Client):
     '''
@@ -326,15 +327,18 @@ class BacklogClient(Client):
         '''
         build_soql = "Select Id from ADM_Build__c where Name like '{}%'".format(release)
         builds = self.sf_session.query(build_soql)
-        soql = "Select Id from ADM_Work__c where Scheduled_Build__c in ('{}')".format("','".join([x['Id'] for x in builds['records']]))
-        if team is not None:
-            soql += " and Scrum_Team__c = '{}'".format(team)
-        if stories_only:
-            soql += " and RecordTypeId = '{}'".format(self.WORK_RECORD_TYPES['User Story'])
-        if open_only:
-            soql += " and Closed__c = 0"
-        result = self.sf_session.query(soql)
-        return [x['Id'] for x in result['records']]
+        if len(builds['records']) > 0:
+            soql = "Select Id from ADM_Work__c where Scheduled_Build__c in ('{}')".format("','".join([x['Id'] for x in builds['records']]))
+            if team is not None:
+                soql += " and Scrum_Team__c = '{}'".format(team)
+            if stories_only:
+                soql += " and RecordTypeId = '{}'".format(self.WORK_RECORD_TYPES['User Story'])
+            if open_only:
+                soql += " and Closed__c = 0"
+            result = self.sf_session.query(soql)
+            return [x['Id'] for x in result['records']]
+        else:
+            return []
     
     def get_team_burndown_remaining(self, team):
         soql = "Select Id from ADM_Work__c where Scrum_Team__c = '{}' and Closed__c = 0 and RecordTypeId = '{}'".format(team, self.WORK_RECORD_TYPES['User Story'])
@@ -379,8 +383,8 @@ class BacklogClient(Client):
         out = []
         for x in result['records']:
             if x['Details__c']:
-                match = re.search("As a .+ ((I can)|(I want)|(I am able)|(I would like)|(I must)) .+", x['Details__c'], re.IGNORECASE|re.DOTALL)
-                if match:
+                p = StoryParser(x['Details__c'])
+                if p.is_functional():
                     out.append(x['Id'])
                 else:
                     parents = self.get_parent_work_for_work(x['Id'])
@@ -396,8 +400,8 @@ class BacklogClient(Client):
         out = []
         for x in result['records']:
             if x['Details__c']:
-                match = re.search("As a .+ ((I can)|(I want)|(I am able)|(I would like)|(I must)) .+ So That", x['Details__c'], re.IGNORECASE|re.DOTALL)
-                if match:
+                p = StoryParser(x['Details__c'])
+                if p.is_complete():
                     out.append(x['Id'])
                 else:
                     parents = self.get_parent_work_for_work(x['Id'])
@@ -406,6 +410,21 @@ class BacklogClient(Client):
                         out.append(x['Id'])
                 
         return out
+    
+    def extract_personas_from_stories(self, stories):
+        soql = "Select Id, Details__c from ADM_Work__c where Id in ('{}')".format("','".join(stories))
+        result = self.sf_session.query(soql)
+        out = {}
+        for x in result['records']:
+            if x['Details__c']:
+                p = StoryParser(x['Details__c'])
+                if p.is_functional():
+                    persona = p.get_persona()
+                    if persona not in out.keys():
+                        out[persona] = 1
+                    else:
+                        out[persona] += 1
+        return out        
 
     
     def get_total_points_for_items(self, work_ids):
@@ -423,3 +442,13 @@ class BacklogClient(Client):
                 
         return out
     
+    def get_themes_for_release(self, release, team=None):
+        work = self.get_work_in_release(release, team=team)
+        return self.get_themes_for_work(work)
+    
+    def get_themes_for_work(self, work):
+        # split up the list
+        soql = "Select Theme__c from ADM_Theme_Assignment__c where Work__c in('{}')".format("','".join(work))
+        result = self.sf_session.query(soql)
+        return [x['Theme__c'] for x in result['records']]
+    
