@@ -12,4 +12,9 @@ class ThemeClient(Client):
     
     def find_work_for_theme(self, themeid):
         result = self.sf_session.query("Select Work__c from ADM_Theme_Assignment__c where Theme__c = '{}'".format(themeid))
+        return [x['Work__c'] for x in result['records']]
+    
+    def filter_work_for_theme(self, workids, themeid):
+        soql = "Select Work__c from ADM_Theme_Assignment__c where Work__c in ('{work}') and Theme__c = '{theme}'".format(work="','".join(workids), theme=themeid)
+        result = self.sf_session.query(soql)
         return [x['Work__c'] for x in result['records']]
\ No newline at end of file
